Cisco.IOS
=========

====== ========================================
Vendor `Cisco Systems <http://www.cisco.com/>`_
OS     IOS
====== ========================================

Cisco.IOS profile supports wide range of IOS-based switches and routers

Tested Equipment
----------------
.. supported:: Cisco.IOS
